@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin-manager.c 6079 2008-01-12 20:18:55Z sdeburca $
+ * $Id: gedit-plugin-manager.c 6640 2008-11-30 16:05:51Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,7 +36,6 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include <glade/glade-xml.h>
 
 #include "gedit-plugin-manager.h"
 #include "gedit-utils.h"
@@ -104,7 +103,7 @@ about_button_cb (GtkWidget          *button,
 		gtk_widget_destroy (pm->priv->about);
 
 	pm->priv->about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
-		"name", gedit_plugin_info_get_name (info),
+		"program-name", gedit_plugin_info_get_name (info),
 		"copyright", gedit_plugin_info_get_copyright (info),
 		"authors", gedit_plugin_info_get_authors (info),
 		"comments", gedit_plugin_info_get_description (info),
@@ -646,7 +645,10 @@ plugin_manager_construct_tree (GeditPluginManager *pm)
 
 	gedit_debug (DEBUG_PLUGINS);
 
-	model = gtk_list_store_new (N_COLUMNS, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, GEDIT_TYPE_PLUGIN_INFO);
+	model = gtk_list_store_new (N_COLUMNS,
+				    G_TYPE_BOOLEAN,
+				    G_TYPE_BOOLEAN,
+				    G_TYPE_POINTER);
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (pm->priv->tree),
 				 GTK_TREE_MODEL (model));
