@@ -27,18 +27,14 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.h 5988 2007-10-28 14:44:53Z sfre $
+ * $Id: gedit-utils.h 6631 2008-11-29 11:06:49Z pborelli $
  */
 
 #ifndef __GEDIT_UTILS_H__
 #define __GEDIT_UTILS_H__
 
 #include <glib.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtktextiter.h>
+#include <gtk/gtk.h>
 #include <atk/atk.h>
 #include <gedit/gedit-encodings.h>
 
@@ -133,19 +129,27 @@ void		 gedit_utils_activate_url		(GtkAboutDialog *about,
 
 gboolean	 gedit_utils_is_valid_uri		(const gchar *uri);
 
-gboolean	 gedit_utils_get_glade_widgets		(const gchar  *filename,
-							 const gchar  *root_node,
+gboolean	 gedit_utils_get_ui_objects		(const gchar  *filename,
+                                                         gchar       **root_objects,
 							 GtkWidget   **error_widget,
-							 const gchar  *widget_name,
+							 const gchar  *object_name,
 							 ...) G_GNUC_NULL_TERMINATED;
 
+gboolean         gedit_utils_file_has_parent            (GFile *gfile);
+
 /* Return NULL if str is not a valid URI and/or filename */
 gchar		*gedit_utils_make_canonical_uri_from_shell_arg
 							(const gchar *str);
 		
-/* Like gnome_vfs_format_uri_for_display but removes the password from the 
- * resulting string */
-gchar		*gedit_utils_format_uri_for_display 	(const gchar *uri);
+gchar		*gedit_utils_uri_for_display 	        (const gchar *uri);
+gchar           *gedit_utils_basename_for_display	(const gchar *uri);
+gboolean	 gedit_utils_decode_uri 		(const gchar *uri,
+							 gchar **scheme,
+							 gchar **user,
+							 gchar **port,
+							 gchar **host,
+							 gchar **path);
+
 
 /* Turns data from a drop into a list of well formatted uris */
 gchar 	       **gedit_utils_drop_get_uris		(GtkSelectionData *selection_data);
