@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window-private.h 5261 2006-10-07 10:16:19Z pborelli $
+ * $Id: gedit-window-private.h 6619 2008-11-25 22:00:16Z jessevdk $
  */
 
 #ifndef __GEDIT_WINDOW_PRIVATE_H__
@@ -66,13 +66,13 @@ struct _GeditWindowPrivate
 	GeditToolbarSetting toolbar_style;
 
 	/* recent files */
-	GtkRecentManager *recent_manager;
 	GtkActionGroup *recents_action_group;
 	guint           recents_menu_ui_id;
+	gulong          recents_handler_id;
 
 	GeditTab       *active_tab;
 	gint            num_tabs;
-	
+
 	gint            num_tabs_with_error;
 
 	gint            width;
@@ -85,11 +85,12 @@ struct _GeditWindowPrivate
 	GeditWindowState state;
 
 	GtkWindowGroup *window_group;
-	
+
 	gchar          *default_path;
 
 	gboolean	removing_tabs : 1;
 	gboolean	destroy_has_run : 1;
+	gboolean	dispose_has_run : 1;
 };
 
 G_END_DECLS
