@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c 6368 2008-08-09 13:37:59Z jessevdk $
+ * $Id: gedit-window.c 6619 2008-11-25 22:00:16Z jessevdk $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -56,6 +56,7 @@
 #include "gedit-enum-types.h"
 
 #define LANGUAGE_NONE (const gchar *)"LangNone"
+#define GEDIT_UIFILE "gedit-ui.xml"
 
 #define GEDIT_WINDOW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object),\
 					 GEDIT_TYPE_WINDOW,                    \
@@ -115,6 +116,8 @@ gedit_window_dispose (GObject *object)
 {
 	GeditWindow *window;
 
+	gedit_debug (DEBUG_WINDOW);
+
 	window = GEDIT_WINDOW (object);
 
 	/* First of all, force collection so that plugins
@@ -122,6 +125,14 @@ gedit_window_dispose (GObject *object)
 	 */
 	gedit_plugins_engine_garbage_collect (gedit_plugins_engine_get_default ());
 
+	/* make sure to deactivate plugins for this window, but only once */
+	if (!window->priv->dispose_has_run)
+	{
+		gedit_plugins_engine_deactivate_plugins (gedit_plugins_engine_get_default (),
+					                  window);
+		window->priv->dispose_has_run = TRUE;
+	}
+
 	if (window->priv->recents_handler_id != 0)
 	{
 		GtkRecentManager *recent_manager;
@@ -143,7 +154,7 @@ gedit_window_dispose (GObject *object)
 		g_object_unref (window->priv->window_group);
 		window->priv->window_group = NULL;
 	}
-
+	
 	/* Now that there have broken some reference loops,
 	 * force collection again.
 	 */
@@ -157,6 +168,8 @@ gedit_window_finalize (GObject *object)
 {
 	GeditWindow *window; 
 
+	gedit_debug (DEBUG_WINDOW);
+
 	window = GEDIT_WINDOW (object);
 
 	g_free (window->priv->default_path);
@@ -784,7 +797,7 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 	update_next_prev_doc_sensitivity (window, tab);
 
 	gedit_plugins_engine_update_plugins_ui (gedit_plugins_engine_get_default (),
-						window, FALSE);
+						 window);
 }
 
 static void
@@ -1380,10 +1393,10 @@ create_menu_bar_and_toolbar (GeditWindow *window,
 	window->priv->quit_action_group = action_group;
 
 	/* now load the UI definition */
-	gtk_ui_manager_add_ui_from_file (manager, GEDIT_UIDIR "gedit-ui.xml", &error);
+	gtk_ui_manager_add_ui_from_file (manager, GEDIT_UIDIR GEDIT_UIFILE, &error);
 	if (error != NULL)
 	{
-		g_warning ("Could not merge gedit-ui.xml: %s", error->message);
+		g_warning ("Could not merge %s: %s", GEDIT_UIFILE, error->message);
 		g_error_free (error);
 	}
 
@@ -1474,18 +1487,9 @@ create_menu_bar_and_toolbar (GeditWindow *window,
 	gtk_menu_tool_button_set_menu (GTK_MENU_TOOL_BUTTON (open_button),
 				       window->priv->toolbar_recent_menu);
 
-	/* not very nice the way we access the tooltops object
-	 * but I can't see a better way and I don't want a differen GtkTooltip
-	 * just for this tool button.
-	 */
-	gtk_tool_item_set_tooltip (open_button,
-				   GTK_TOOLBAR (window->priv->toolbar)->tooltips,
-				   _("Open a file"),
-				   NULL);
-	gtk_menu_tool_button_set_arrow_tooltip (GTK_MENU_TOOL_BUTTON (open_button),
-						GTK_TOOLBAR (window->priv->toolbar)->tooltips,
-						_("Open a recently used file"),
-						NULL);
+	gtk_tool_item_set_tooltip_text (open_button, _("Open a file"));
+	gtk_menu_tool_button_set_arrow_tooltip_text (GTK_MENU_TOOL_BUTTON (open_button),
+						     _("Open a recently used file"));
 
 	action = gtk_action_group_get_action (window->priv->always_sensitive_action_group,
 					      "FileOpen");
@@ -2262,7 +2266,7 @@ sync_name (GeditTab    *tab,
 	g_free (tip);
 
 	gedit_plugins_engine_update_plugins_ui (gedit_plugins_engine_get_default (),
-						window, FALSE);
+						 window);
 }
 
 static GeditWindow *
@@ -2467,7 +2471,7 @@ editable_changed (GeditView  *view,
                   GeditWindow *window)
 {
 	gedit_plugins_engine_update_plugins_ui (gedit_plugins_engine_get_default (),
-						window, FALSE);
+						 window);
 }
 
 static void
@@ -2650,7 +2654,7 @@ notebook_tab_removed (GeditNotebook *notebook,
 		gtk_action_set_sensitive (action, FALSE);
 
 		gedit_plugins_engine_update_plugins_ui (gedit_plugins_engine_get_default (),
-							window, FALSE);
+							 window);
 	}
 
 	if (window->priv->num_tabs <= 1)
@@ -3072,6 +3076,7 @@ gedit_window_init (GeditWindow *window)
 	window->priv->removing_tabs = FALSE;
 	window->priv->state = GEDIT_WINDOW_STATE_NORMAL;
 	window->priv->destroy_has_run = FALSE;
+	window->priv->dispose_has_run = FALSE;
 
 	window->priv->window_group = gtk_window_group_new ();
 	gtk_window_group_add_window (window->priv->window_group, GTK_WINDOW (window));
@@ -3210,8 +3215,9 @@ gedit_window_init (GeditWindow *window)
 			  NULL);
 
 	gedit_debug_message (DEBUG_WINDOW, "Update plugins ui");
-	gedit_plugins_engine_update_plugins_ui (gedit_plugins_engine_get_default (),
-						window, TRUE);
+	
+	gedit_plugins_engine_activate_plugins (gedit_plugins_engine_get_default (),
+					        window);
 
 	/* set visibility of panes.
 	 * This needs to be done after plugins activatation */
@@ -3616,6 +3622,15 @@ _gedit_window_set_saving_session_state (GeditWindow *window,
 	}
 }
 
+/**
+ * gedit_window_get_tab_from_location:
+ * @window: a #GeditWindow
+ * @location: a #GFile
+ *
+ * Gets the #GeditTab that matches with the given @location.
+ *
+ * Returns: the #GeditTab that matches with the given @location.
+ */
 GeditTab *
 gedit_window_get_tab_from_location (GeditWindow *window,
 				    GFile       *location)
